@@ -47,11 +47,7 @@ if ($page == 'customers'
 			'c.traffic_used' => $lng['customer']['traffic'] . ' (' . $lng['panel']['used'] . ')'
 		);
 
-		if ($settings['system']['backup_enabled'] == '1') {
-			$field['c.backup_allowed'] = $lng['backup_allowed'];
-		}
-
-		$paging = new paging($userinfo, TABLE_PANEL_CUSTOMERS, $fields, $settings['panel']['paging'], $settings['panel']['natsorting']);
+		$paging = new paging($userinfo, TABLE_PANEL_CUSTOMERS, $fields);
 		$customers = '';
 		$result_stmt = Database::prepare("
 			SELECT `c`.*, `a`.`loginname` AS `adminname`
@@ -60,7 +56,7 @@ if ($page == 'customers'
 			($userinfo['customers_see_all'] ? '' : " `c`.`adminid` = :adminid AND ") . "
 			`c`.`adminid` = `a`.`adminid` " .
 			$paging->getSqlWhere(true) . " " .
-			$paging->getSqlOrderBy($settings['panel']['natsorting']) . " " .
+			$paging->getSqlOrderBy() . " " .
 			$paging->getSqlLimit()
 		);
 		Database::pexecute($result_stmt, array('adminid' => $userinfo['adminid']));
@@ -87,10 +83,11 @@ if ($page == 'customers'
 				Database::pexecute($domains_stmt, array('cid' => $row['customerid'], 'stdd' => $row['standardsubdomain']));
 				$domains = $domains_stmt->fetch(PDO::FETCH_ASSOC);
 				$row['domains'] = intval($domains['domains']);
-				$row['traffic_used'] = round($row['traffic_used'] / (1024 * 1024), $settings['panel']['decimal_places']);
-				$row['traffic'] = round($row['traffic'] / (1024 * 1024), $settings['panel']['decimal_places']);
-				$row['diskspace_used'] = round($row['diskspace_used'] / 1024, $settings['panel']['decimal_places']);
-				$row['diskspace'] = round($row['diskspace'] / 1024, $settings['panel']['decimal_places']);
+				$dec_places = Settings::Get('panel.decimal_places');
+				$row['traffic_used'] = round($row['traffic_used'] / (1024 * 1024), $dec_places);
+				$row['traffic'] = round($row['traffic'] / (1024 * 1024), $dec_places);
+				$row['diskspace_used'] = round($row['diskspace_used'] / 1024, $dec_places);
+				$row['diskspace'] = round($row['diskspace'] / 1024, $dec_places);
 				$last_login = ((int)$row['lastlogin_succ'] == 0) ? $lng['panel']['neverloggedin'] : date('d.m.Y', $row['lastlogin_succ']);
 
 				/**
@@ -114,13 +111,13 @@ if ($page == 'customers'
 				}
 
 				$islocked = 0;
-				if ($row['loginfail_count'] >= $settings['login']['maxloginattempts']
-					&& $row['lastlogin_fail'] > (time() - $settings['login']['deactivatetime'])
+				if ($row['loginfail_count'] >= Settings::Get('login.maxloginattempts')
+					&& $row['lastlogin_fail'] > (time() - Settings::Get('login.deactivatetime'))
 				) {
 					$islocked = 1;
 				}
 
-				$row = str_replace_array('-1', 'UL', $row, 'diskspace traffic mysqls emails email_accounts email_forwarders ftps tickets subdomains email_autoresponder');
+				$row = str_replace_array('-1', 'UL', $row, 'diskspace traffic mysqls emails email_accounts email_forwarders ftps tickets subdomains');
 				$row = htmlentities_array($row);
 				eval("\$customers.=\"" . getTemplate("customers/customers_customer") . "\";");
 				$count++;
@@ -251,7 +248,7 @@ if ($page == 'customers'
 				Database::needRoot(true);
 				$last_dbserver = 0;
 
-				$dbm = new DbManager($settings, $log);
+				$dbm = new DbManager($log);
 
 				while ($row_database = $databases_stmt->fetch(PDO::FETCH_ASSOC)) {
 
@@ -270,6 +267,13 @@ if ($page == 'customers'
 				Database::pexecute($stmt, array('id' => $id));
 				$stmt = Database::prepare("DELETE FROM `" . TABLE_PANEL_DATABASES . "` WHERE `customerid` = :id");
 				Database::pexecute($stmt, array('id' => $id));
+				// first gather all domain-id's to clean up panel_domaintoip accordingly
+				$did_stmt = Database::prepare("SELECT `id` FROM `".TABLE_PANEL_DOMAINS."` WHERE `customerid` = :id");
+				Database::pexecute($did_stmt, array('id' => $id));
+				while ($row = $did_stmt->fetch(PDO::FETCH_ASSOC)) {
+					$stmt = Database::prepare("DELETE FROM `" . TABLE_DOMAINTOIP . "` WHERE `id_domain` = :did");
+					Database::pexecute($stmt, array('did' => $row['id']));
+				}
 				$stmt = Database::prepare("DELETE FROM `" . TABLE_PANEL_DOMAINS . "` WHERE `customerid` = :id");
 				Database::pexecute($stmt, array('id' => $id));
 				$domains_deleted = $stmt->rowCount();
@@ -295,8 +299,6 @@ if ($page == 'customers'
 				Database::pexecute($stmt, array('id' => $id));
 				$stmt = Database::prepare("DELETE FROM `" . TABLE_FTP_USERS . "` WHERE `customerid` = :id");
 				Database::pexecute($stmt, array('id' => $id));
-				$stmt = Database::prepare("DELETE FROM `" . TABLE_MAIL_AUTORESPONDER . "` WHERE `customerid` = :id");
-				Database::pexecute($stmt, array('id' => $id));
 
 				// Delete all waiting "create user" -tasks for this user, #276
 				// Note: the WHERE selects part of a serialized array, but it should be safe this way
@@ -306,26 +308,6 @@ if ($page == 'customers'
 				);
 				Database::pexecute($del_stmt, array('loginname' => "%:{$result['loginname']};%"));
 
-				// remove everything APS-related, #216
-				$apsresult_stmt = Database::prepare("SELECT `ID` FROM `".TABLE_APS_INSTANCES."` WHERE `CustomerID` = :id");
-				Database::pexecute($apsresult_stmt, array('id' => $id));
-
-				while ($apsrow = $apsresult_stmt->fetch(PDO::FETCH_ASSOC)) {
-					// remove all package related settings
-					$del_stmt = Database::prepare("DELETE FROM `".TABLE_APS_SETTINGS."` WHERE `InstanceID` = :iid");
-					Database::pexecute($del_stmt, array('iid' => $apsrow['ID']));
-					// maybe some leftovers in the tasks
-					$del_stmt = Database::prepare("DELETE FROM `".TABLE_APS_TASKS."` WHERE `InstanceID` = :iid");
-					Database::pexecute($del_stmt, array('iid' => $apsrow['ID']));
-				}
-				// now remove all user instances
-				$stmt = Database::prepare("DELETE FROM `".TABLE_APS_INSTANCES."` WHERE `CustomerID` = :id");
-				Database::pexecute($stmt, array('id' => $id));
-				// eventually some temp-setting-leftovers
-				$stmt = Database::prepare("DELETE FROM `".TABLE_APS_TEMP_SETTINGS."` WHERE `CustomerID` = :id");
-				Database::pexecute($stmt, array('id' => $id));
-				// eof APS-related removings, #216
-
 				$admin_update_query = "UPDATE `" . TABLE_PANEL_ADMINS . "` SET `customers_used` = `customers_used` - 1 ";
 				$admin_update_query.= ", `domains_used` = `domains_used` - 0" . (int)($domains_deleted - $result['subdomains_used']);
 
@@ -349,10 +331,6 @@ if ($page == 'customers'
 					$admin_update_query.= ", `email_quota_used` = `email_quota_used` - 0" . (int)$result['email_quota'];
 				}
 
-				if ($result['email_autoresponder'] != '-1') {
-					$admin_update_query.= ", `email_autoresponder_used` = `email_autoresponder_used` - 0" . (int)$result['email_autoresponder'];
-				}
-
 				if ($result['subdomains'] != '-1') {
 					$admin_update_query.= ", `subdomains_used` = `subdomains_used` - 0" . (int)$result['subdomains'];
 				}
@@ -365,10 +343,6 @@ if ($page == 'customers'
 					$admin_update_query.= ", `tickets_used` = `tickets_used` - 0" . (int)$result['tickets'];
 				}
 
-				if ($result['aps_packages'] != '-1') {
-					$admin_update_query.= ", `aps_packages_used` = `aps_packages_used` - 0" . (int)$result['aps_packages'];
-				}
-
 				if (($result['diskspace'] / 1024) != '-1') {
 					$admin_update_query.= ", `diskspace_used` = `diskspace_used` - 0" . (int)$result['diskspace'];
 				}
@@ -397,7 +371,7 @@ if ($page == 'customers'
 				if ($tickets !== false && isset($tickets[0])) {
 					foreach ($tickets as $ticket) {
 						$now = time();
-						$mainticket = ticket::getInstanceOf($userinfo, $settings, (int)$ticket);
+						$mainticket = ticket::getInstanceOf($userinfo, (int)$ticket);
 						$mainticket->Set('lastchange', $now, true, true);
 						$mainticket->Set('lastreplier', '1', true, true);
 						$mainticket->Set('status', '3', true, true);
@@ -464,7 +438,7 @@ if ($page == 'customers'
 					$email_forwarders = - 1;
 				}
 
-				if ($settings['system']['mail_quota_enabled'] == '1') {
+				if (Settings::Get('system.mail_quota_enabled') == '1') {
 					$email_quota = validate($_POST['email_quota'], 'email_quota', '/^\d+$/', 'vmailquotawrong', array('0', ''));
 					if (isset($_POST['email_quota_ul'])) {
 						$email_quota = - 1;
@@ -473,15 +447,6 @@ if ($page == 'customers'
 					$email_quota = - 1;
 				}
 
-				if ($settings['autoresponder']['autoresponder_active'] == '1') {
-					$email_autoresponder = intval_ressource($_POST['email_autoresponder']);
-					if (isset($_POST['email_autoresponder_ul'])) {
-						$email_autoresponder = - 1;
-					}
-				} else {
-					$email_autoresponder = 0;
-				}
-
 				$email_imap = 0;
 				if (isset($_POST['email_imap'])) {
 					$email_imap = intval_ressource($_POST['email_imap']);
@@ -500,9 +465,9 @@ if ($page == 'customers'
 					$ftps = - 1;
 				}
 
-				$tickets = ($settings['ticket']['enabled'] == 1 ? intval_ressource($_POST['tickets']) : 0);
+				$tickets = (Settings::Get('ticket.enabled') == 1 ? intval_ressource($_POST['tickets']) : 0);
 				if (isset($_POST['tickets_ul'])
-					&& $settings['ticket']['enabled'] == '1'
+					&& Settings::Get('ticket.enabled') == '1'
 				) {
 					$tickets = - 1;
 				}
@@ -512,15 +477,6 @@ if ($page == 'customers'
 					$mysqls = - 1;
 				}
 
-				if ($settings['aps']['aps_active'] == '1') {
-					$number_of_aps_packages = intval_ressource($_POST['number_of_aps_packages']);
-					if (isset($_POST['number_of_aps_packages_ul'])) {
-						$number_of_aps_packages = - 1;
-					}
-				} else {
-					$number_of_aps_packages = 0;
-				}
-
 				$createstdsubdomain = 0;
 				if(isset($_POST['createstdsubdomain'])) {
 					$createstdsubdomain = intval($_POST['createstdsubdomain']);
@@ -533,15 +489,6 @@ if ($page == 'customers'
 					$password = validatePassword($password);
 				}
 
-				$backup_allowed = 0;
-				if (isset($_POST['backup_allowed'])) {
-					$backup_allowed = intval($_POST['backup_allowed']);
-				}
-
-				if ($backup_allowed != 0) {
-					$backup_allowed = 1;
-				}
-
 				// gender out of range? [0,2]
 				if ($gender < 0 || $gender > 2) {
 					$gender = 0;
@@ -575,23 +522,19 @@ if ($page == 'customers'
 				   || ((($userinfo['emails_used'] + $emails) > $userinfo['emails']) && $userinfo['emails'] != '-1')
 				   || ((($userinfo['email_accounts_used'] + $email_accounts) > $userinfo['email_accounts']) && $userinfo['email_accounts'] != '-1')
 				   || ((($userinfo['email_forwarders_used'] + $email_forwarders) > $userinfo['email_forwarders']) && $userinfo['email_forwarders'] != '-1')
-				   || ((($userinfo['email_quota_used'] + $email_quota) > $userinfo['email_quota']) && $userinfo['email_quota'] != '-1' && $settings['system']['mail_quota_enabled'] == '1')
-				   || ((($userinfo['email_autoresponder_used'] + $email_autoresponder) > $userinfo['email_autoresponder']) && $userinfo['email_autoresponder'] != '-1' && $settings['autoresponder']['autoresponder_active'] == '1')
+				   || ((($userinfo['email_quota_used'] + $email_quota) > $userinfo['email_quota']) && $userinfo['email_quota'] != '-1' && Settings::Get('system.mail_quota_enabled') == '1')
 				   || ((($userinfo['ftps_used'] + $ftps) > $userinfo['ftps']) && $userinfo['ftps'] != '-1')
 				   || ((($userinfo['tickets_used'] + $tickets) > $userinfo['tickets']) && $userinfo['tickets'] != '-1')
 				   || ((($userinfo['subdomains_used'] + $subdomains) > $userinfo['subdomains']) && $userinfo['subdomains'] != '-1')
-				   || ((($userinfo['aps_packages_used'] + $number_of_aps_packages) > $userinfo['aps_packages']) && $userinfo['aps_packages'] != '-1' && $settings['aps']['aps_active'] == '1')
 				   || (($diskspace / 1024) == '-1' && ($userinfo['diskspace'] / 1024) != '-1')
 				   || ($mysqls == '-1' && $userinfo['mysqls'] != '-1')
 				   || ($emails == '-1' && $userinfo['emails'] != '-1')
 				   || ($email_accounts == '-1' && $userinfo['email_accounts'] != '-1')
 				   || ($email_forwarders == '-1' && $userinfo['email_forwarders'] != '-1')
-				   || ($email_quota == '-1' && $userinfo['email_quota'] != '-1' && $settings['system']['mail_quota_enabled'] == '1')
-				   || ($email_autoresponder == '-1' && $userinfo['email_autoresponder'] != '-1' && $settings['autoresponder']['autoresponder_active'] == '1')
+				   || ($email_quota == '-1' && $userinfo['email_quota'] != '-1' && Settings::Get('system.mail_quota_enabled') == '1')
 				   || ($ftps == '-1' && $userinfo['ftps'] != '-1')
 				   || ($tickets == '-1' && $userinfo['tickets'] != '-1')
 				   || ($subdomains == '-1' && $userinfo['subdomains'] != '-1')
-				   || ($number_of_aps_packages == '-1' && $userinfo['aps_packages'] != '-1')
 				) {
 					standard_error('youcantallocatemorethanyouhave');
 					exit;
@@ -615,12 +558,12 @@ if ($page == 'customers'
 					if (isset($_POST['new_loginname'])
 						&& $_POST['new_loginname'] != ''
 					) {
-						$accountnumber = intval($settings['system']['lastaccountnumber']);
+						$accountnumber = intval(Settings::Get('system.lastaccountnumber'));
 						$loginname = validate($_POST['new_loginname'], 'loginname', '/^[a-z][a-z0-9\-_]+$/i');
 
 						// Accounts which match systemaccounts are not allowed, filtering them
-						if (preg_match('/^' . preg_quote($settings['customer']['accountprefix'], '/') . '([0-9]+)/', $loginname)) {
-							standard_error('loginnameissystemaccount', $settings['customer']['accountprefix']);
+						if (preg_match('/^' . preg_quote(Settings::Get('customer.accountprefix'), '/') . '([0-9]+)/', $loginname)) {
+							standard_error('loginnameissystemaccount', Settings::Get('customer.accountprefix'));
 						}
 
 						// Additional filtering for Bug #962
@@ -628,12 +571,12 @@ if ($page == 'customers'
 								&& !in_array("posix_getpwnam", explode(",", ini_get('disable_functions')))
 								&& posix_getpwnam($loginname)
 						) {
-							standard_error('loginnameissystemaccount', $settings['customer']['accountprefix']);
+							standard_error('loginnameissystemaccount', Settings::Get('customer.accountprefix'));
 						}
 
 					} else {
-						$accountnumber = intval($settings['system']['lastaccountnumber']) + 1;
-						$loginname = $settings['customer']['accountprefix'] . $accountnumber;
+						$accountnumber = intval(Settings::Get('system.lastaccountnumber')) + 1;
+						$loginname = Settings::Get('customer.accountprefix') . $accountnumber;
 					}
 
 					// Check if the account already exists
@@ -652,16 +595,16 @@ if ($page == 'customers'
 					) {
 						standard_error('loginnameexists', $loginname);
 
-					} elseif (!validateUsername($loginname, $settings['panel']['unix_names'], 14 - strlen($settings['customer']['mysqlprefix']))) {
-						if (strlen($loginname) > 14 - strlen($settings['customer']['mysqlprefix'])) {
-							standard_error('loginnameiswrong2', 14 - strlen($settings['customer']['mysqlprefix']));
+					} elseif (!validateUsername($loginname, Settings::Get('panel.unix_names'), 14 - strlen(Settings::Get('customer.mysqlprefix')))) {
+						if (strlen($loginname) > 14 - strlen(Settings::Get('customer.mysqlprefix'))) {
+							standard_error('loginnameiswrong2', 14 - strlen(Settings::Get('customer.mysqlprefix')));
 						} else {
 							standard_error('loginnameiswrong', $loginname);
 						}
 					}
 
-					$guid = intval($settings['system']['lastguid']) + 1;
-					$documentroot = makeCorrectDir($settings['system']['documentroot_prefix'] . '/' . $loginname);
+					$guid = intval(Settings::Get('system.lastguid')) + 1;
+					$documentroot = makeCorrectDir(Settings::Get('system.documentroot_prefix') . '/' . $loginname);
 
 					if (file_exists($documentroot)) {
 						standard_error('documentrootexists', $documentroot);
@@ -683,7 +626,7 @@ if ($page == 'customers'
 						$password = substr(md5(uniqid(microtime(), 1)), 12, 6);
 					}
 
-					$_theme = $settings['panel']['default_theme'];
+					$_theme = Settings::Get('panel.default_theme');
 
 					$ins_data = array(
 						'adminid' => $userinfo['adminid'],
@@ -716,11 +659,8 @@ if ($page == 'customers'
 						'phpenabled' => $phpenabled,
 						'imap' => $email_imap,
 						'pop3' => $email_pop3,
-						'aps' => $number_of_aps_packages,
 						'perlenabled' => $perlenabled,
-						'email_autoresponder' => $email_autoresponder,
-						'backup_allowed' => $backup_allowed,
-						'theme' => $theme
+						'theme' => $_theme
 					);
 
 					$ins_stmt = Database::prepare("
@@ -756,10 +696,7 @@ if ($page == 'customers'
 						`phpenabled` = :phpenabled,
 						`imap` = :imap,
 						`pop3` = :pop3,
-						`aps_packages` = :aps,
 						`perlenabled` = :perlenabled,
-						`email_autoresponder` = :email_autoresponder,
-						`backup_allowed` = :backup_allowed,
 						`theme` = :theme"
 					);
 					Database::pexecute($ins_stmt, $ins_data);
@@ -788,12 +725,6 @@ if ($page == 'customers'
 						$admin_update_query.= ", `email_quota_used` = `email_quota_used` + 0" . (int)$email_quota;
 					}
 
-					if ($email_autoresponder != '-1'
-						&& $settings['autoresponder']['autoresponder_active'] == 1
-					) {
-						$admin_update_query.= ", `email_autoresponder_used` = `email_autoresponder_used` + 0" . (int)$email_autoresponder;
-					}
-
 					if ($subdomains != '-1') {
 						$admin_update_query.= ", `subdomains_used` = `subdomains_used` + 0" . (int)$subdomains;
 					}
@@ -803,7 +734,7 @@ if ($page == 'customers'
 					}
 
 					if ($tickets != '-1'
-						&& $settings['ticket']['enabled'] == 1
+						&& Settings::Get('ticket.enabled') == 1
 					) {
 						$admin_update_query.= ", `tickets_used` = `tickets_used` + 0" . (int)$tickets;
 					}
@@ -812,10 +743,6 @@ if ($page == 'customers'
 						$admin_update_query.= ", `diskspace_used` = `diskspace_used` + 0" . (int)$diskspace;
 					}
 
-					if ($number_of_aps_packages != '-1') {
-						$admin_update_query.= ", `aps_packages_used` = `aps_packages_used` + 0" . (int)$number_of_aps_packages;
-					}
-
 					$admin_update_query.= " WHERE `adminid` = '" . (int)$userinfo['adminid'] . "'";
 					Database::query($admin_update_query);
 
@@ -826,7 +753,7 @@ if ($page == 'customers'
 					);
 					Database::pexecute($upd_stmt, array('guid' => $guid));
 
-					if ($accountnumber != intval($settings['system']['lastaccountnumber'])) {
+					if ($accountnumber != intval(Settings::Get('system.lastaccountnumber'))) {
 						$upd_stmt = Database::prepare("
 						UPDATE `" . TABLE_PANEL_SETTINGS . "` SET
 							`value` = :accno
@@ -862,7 +789,7 @@ if ($page == 'customers'
 						'passwd' => $htpasswdPassword
 					);
 
-					if ($settings['system']['awstats_enabled'] == '1') {
+					if (Settings::Get('system.awstats_enabled') == '1') {
 						$ins_data['path'] = makeCorrectDir($documentroot . '/awstats/');
 						$log->logAction(ADM_ACTION, LOG_NOTICE, "automatically added awstats htpasswd for user '" . $loginname . "'");
 					} else {
@@ -875,7 +802,7 @@ if ($page == 'customers'
 					$cryptPassword = makeCryptPassword($password);
 					// FTP-User
 					$ins_stmt = Database::prepare("
-						INSERT INTO `" . TABLE_FTP_USERS . "` SET `customerid` = :customerid, `username` = :username,
+						INSERT INTO `" . TABLE_FTP_USERS . "` SET `customerid` = :customerid, `username` = :username, `description` = :desc,
 							`password` = :passwd, `homedir` = :homedir, `login_enabled` = 'y', `uid` = :guid, `gid` = :guid"
 					);
 					$ins_data = array(
@@ -883,7 +810,8 @@ if ($page == 'customers'
 						'username' => $loginname,
 						'passwd' => $cryptPassword,
 						'homedir' => $documentroot,
-						'guid' => $guid
+						'guid' => $guid,
+						'desc' => "Default"
 					);
 					Database::pexecute($ins_stmt, $ins_data);
 					// FTP-Group
@@ -894,7 +822,7 @@ if ($page == 'customers'
 							'customerid' => $customerid,
 							'groupname' => $loginname,
 							'guid' => $guid,
-							'members' => $loginname
+							'members' => $loginname.','.Settings::Get('system.httpuser')
 					);
 					Database::pexecute($ins_stmt, $ins_data);
 					// FTP-Quotatallies
@@ -909,12 +837,12 @@ if ($page == 'customers'
 
 					if ($createstdsubdomain == '1') {
 
-						if (isset($settings['system']['stdsubdomain'])
-							&& $settings['system']['stdsubdomain'] != ''
+						if (Settings::Get('system.stdsubdomain') !== null
+							&& Settings::Get('system.stdsubdomain') != ''
 						) {
-							$_stdsubdomain = $loginname . '.' . $settings['system']['stdsubdomain'];
+							$_stdsubdomain = $loginname . '.' . Settings::Get('system.stdsubdomain');
 						} else {
-							$_stdsubdomain = $loginname . '.' . $settings['system']['hostname'];
+							$_stdsubdomain = $loginname . '.' . Settings::Get('system.hostname');
 						}
 
 						$ins_data = array(
@@ -937,6 +865,9 @@ if ($page == 'customers'
 							`openbasedir` = '1',
 							`speciallogfile` = '0',
 							`specialsettings` = '',
+							`dkim_id` = '0',
+							`dkim_privkey` = '',
+							`dkim_pubkey` = '',
 							`add_date` = :adddate"
 						);
 						Database::pexecute($ins_stmt, $ins_data);
@@ -946,7 +877,7 @@ if ($page == 'customers'
 						$ins_stmt = Database::prepare("
 							INSERT INTO `".TABLE_DOMAINTOIP."` SET `id_domain` = :domainid, `id_ipandports` = :ipid"
 						);
-						Database::pexecute($ins_stmt, array('domainid' => $domainid, 'ipid' => $settings['system']['defaultip']));
+						Database::pexecute($ins_stmt, array('domainid' => $domainid, 'ipid' => Settings::Get('system.defaultip')));
 
 						$upd_stmt = Database::prepare("
 							UPDATE `" . TABLE_PANEL_CUSTOMERS . "` SET `standardsubdomain` = :domainid WHERE `customerid` = :customerid"
@@ -958,8 +889,8 @@ if ($page == 'customers'
 
 					if ($sendpassword == '1') {
 
-						$srv_hostname = $settings['system']['hostname'];
-						if ($settings['system']['froxlordirectlyviahostname'] == '0') {
+						$srv_hostname = Settings::Get('system.hostname');
+						if (Settings::Get('system.froxlordirectlyviahostname') == '0') {
 							$srv_hostname .= '/froxlor';
 						}
 
@@ -967,7 +898,7 @@ if ($page == 'customers'
 							SELECT ip, port FROM `".TABLE_PANEL_IPSANDPORTS."`
 							WHERE `id` = :defaultip
 						");
-						$srv_ip = Database::pexecute_first($srv_ip_stmt, array('defaultip' => $settings['system']['defaultip']));
+						$srv_ip = Database::pexecute_first($srv_ip_stmt, array('defaultip' => Settings::Get('system.defaultip')));
 
 						$replace_arr = array(
 							'FIRSTNAME' => $firstname,
@@ -1027,7 +958,7 @@ if ($page == 'customers'
 				$language_options = '';
 
 				while (list($language_file, $language_name) = each($languages)) {
-					$language_options.= makeoption($language_name, $language_file, $settings['panel']['standardlanguage'], true);
+					$language_options.= makeoption($language_name, $language_file, Settings::Get('panel.standardlanguage'), true);
 				}
 
 				$diskspace_ul = makecheckbox('diskspace_ul', $lng['customer']['unlimited'], '-1', false, '0', true, true);
@@ -1037,11 +968,9 @@ if ($page == 'customers'
 				$email_accounts_ul = makecheckbox('email_accounts_ul', $lng['customer']['unlimited'], '-1', false, '0', true, true);
 				$email_forwarders_ul = makecheckbox('email_forwarders_ul', $lng['customer']['unlimited'], '-1', false, '0', true, true);
 				$email_quota_ul = makecheckbox('email_quota_ul', $lng['customer']['unlimited'], '-1', false, '0', true, true);
-				$email_autoresponder_ul = makecheckbox('email_autoresponder_ul', $lng['customer']['unlimited'], '-1', false, '0', true, true);
 				$ftps_ul = makecheckbox('ftps_ul', $lng['customer']['unlimited'], '-1', false, '0', true, true);
 				$tickets_ul = makecheckbox('tickets_ul', $lng['customer']['unlimited'], '-1', false, '0', true, true);
 				$mysqls_ul = makecheckbox('mysqls_ul', $lng['customer']['unlimited'], '-1', false, '0', true, true);
-				$number_of_aps_packages_ul = makecheckbox('number_of_aps_packages_ul', $lng['customer']['unlimited'], '-1', false, '0', true, true);
 
 				$gender_options = makeoption($lng['gender']['undef'], 0, true, true, true);
 				$gender_options .= makeoption($lng['gender']['male'], 1, null, true, true);
@@ -1121,7 +1050,7 @@ if ($page == 'customers'
 					$email_forwarders = - 1;
 				}
 
-				if ($settings['system']['mail_quota_enabled'] == '1') {
+				if (Settings::Get('system.mail_quota_enabled') == '1') {
 					$email_quota = validate($_POST['email_quota'], 'email_quota', '/^\d+$/', 'vmailquotawrong', array('0', ''));
 					if (isset($_POST['email_quota_ul'])) {
 						$email_quota = - 1;
@@ -1130,15 +1059,6 @@ if ($page == 'customers'
 					$email_quota = - 1;
 				}
 
-				if ($settings['autoresponder']['autoresponder_active'] == '1') {
-					$email_autoresponder = intval_ressource($_POST['email_autoresponder']);
-					if (isset($_POST['email_autoresponder_ul'])) {
-						$email_autoresponder = - 1;
-					}
-				} else {
-					$email_autoresponder = 0;
-				}
-
 				$email_imap = 0;
 				if (isset($_POST['email_imap'])) {
 					$email_imap = intval_ressource($_POST['email_imap']);
@@ -1157,21 +1077,13 @@ if ($page == 'customers'
 					$ftps = - 1;
 				}
 
-				$tickets = ($settings['ticket']['enabled'] == 1 ? intval_ressource($_POST['tickets']) : 0);
+				$tickets = (Settings::Get('ticket.enabled') == 1 ? intval_ressource($_POST['tickets']) : 0);
 				if (isset($_POST['tickets_ul'])
-					&& $settings['ticket']['enabled'] == '1'
+					&& Settings::Get('ticket.enabled') == '1'
 				) {
 					$tickets = - 1;
 				}
 
-				$backup_allowed = 0;
-				if (isset($_POST['backup_allowed'])) {
-					$backup_allowed = intval($_POST['backup_allowed']);
-				}
-				if ($backup_allowed != '0') {
-					$backup_allowed = 1;
-				}
-
 				// gender out of range? [0,2]
 				if ($gender < 0 || $gender > 2) {
 					$gender = 0;
@@ -1185,15 +1097,6 @@ if ($page == 'customers'
 					$mysqls = - 1;
 				}
 
-				if ($settings['aps']['aps_active'] == '1') {
-					$number_of_aps_packages = intval_ressource($_POST['number_of_aps_packages']);
-					if (isset($_POST['number_of_aps_packages_ul'])) {
-						$number_of_aps_packages = - 1;
-					}
-				} else {
-					$number_of_aps_packages = 0;
-				}
-
 				$createstdsubdomain = 0;
 				if (isset($_POST['createstdsubdomain'])) {
 					$createstdsubdomain = intval($_POST['createstdsubdomain']);
@@ -1222,23 +1125,19 @@ if ($page == 'customers'
 				   || ((($userinfo['emails_used'] + $emails - $result['emails']) > $userinfo['emails']) && $userinfo['emails'] != '-1')
 				   || ((($userinfo['email_accounts_used'] + $email_accounts - $result['email_accounts']) > $userinfo['email_accounts']) && $userinfo['email_accounts'] != '-1')
 				   || ((($userinfo['email_forwarders_used'] + $email_forwarders - $result['email_forwarders']) > $userinfo['email_forwarders']) && $userinfo['email_forwarders'] != '-1')
-				   || ((($userinfo['email_quota_used'] + $email_quota - $result['email_quota']) > $userinfo['email_quota']) && $userinfo['email_quota'] != '-1' && $settings['system']['mail_quota_enabled'] == '1')
-				   || ((($userinfo['email_autoresponder_used'] + $email_autoresponder - $result['email_autoresponder']) > $userinfo['email_autoresponder']) && $userinfo['email_autoresponder'] != '-1' && $settings['autoresponder']['autoresponder_active'] == '1')
+				   || ((($userinfo['email_quota_used'] + $email_quota - $result['email_quota']) > $userinfo['email_quota']) && $userinfo['email_quota'] != '-1' && Settings::Get('system.mail_quota_enabled') == '1')
 				   || ((($userinfo['ftps_used'] + $ftps - $result['ftps']) > $userinfo['ftps']) && $userinfo['ftps'] != '-1')
 				   || ((($userinfo['tickets_used'] + $tickets - $result['tickets']) > $userinfo['tickets']) && $userinfo['tickets'] != '-1')
 				   || ((($userinfo['subdomains_used'] + $subdomains - $result['subdomains']) > $userinfo['subdomains']) && $userinfo['subdomains'] != '-1')
 				   || (($diskspace / 1024) == '-1' && ($userinfo['diskspace'] / 1024) != '-1')
-				   || ((($userinfo['aps_packages'] + $number_of_aps_packages - $result['aps_packages']) > $userinfo['aps_packages']) && $userinfo['aps_packages'] != '-1' && $settings['aps']['aps_active'] == '1')
 				   || ($mysqls == '-1' && $userinfo['mysqls'] != '-1')
 				   || ($emails == '-1' && $userinfo['emails'] != '-1')
 				   || ($email_accounts == '-1' && $userinfo['email_accounts'] != '-1')
 				   || ($email_forwarders == '-1' && $userinfo['email_forwarders'] != '-1')
-				   || ($email_quota == '-1' && $userinfo['email_quota'] != '-1' && $settings['system']['mail_quota_enabled'] == '1')
-				   || ($email_autoresponder == '-1' && $userinfo['email_autoresponder'] != '-1' && $settings['autoresponder']['autoresponder_active'] == '1')
+				   || ($email_quota == '-1' && $userinfo['email_quota'] != '-1' && Settings::Get('system.mail_quota_enabled') == '1')
 				   || ($ftps == '-1' && $userinfo['ftps'] != '-1')
 				   || ($tickets == '-1' && $userinfo['tickets'] != '-1')
 				   || ($subdomains == '-1' && $userinfo['subdomains'] != '-1')
-				   || ($number_of_aps_packages == '-1' && $userinfo['aps_packages'] != '-1')
 				) {
 					standard_error('youcantallocatemorethanyouhave');
 					exit;
@@ -1274,12 +1173,12 @@ if ($page == 'customers'
 						&& $result['standardsubdomain'] == '0'
 					) {
 
-						if (isset($settings['system']['stdsubdomain'])
-							&& $settings['system']['stdsubdomain'] != ''
+						if (Settings::Get('system.stdsubdomain') !== null
+							&& Settings::Get('system.stdsubdomain') != ''
 						) {
-							$_stdsubdomain = $result['loginname'] . '.' . $settings['system']['stdsubdomain'];
+							$_stdsubdomain = $result['loginname'] . '.' . Settings::Get('system.stdsubdomain');
 						} else {
-							$_stdsubdomain = $result['loginname'] . '.' . $settings['system']['hostname'];
+							$_stdsubdomain = $result['loginname'] . '.' . Settings::Get('system.hostname');
 						}
 
 						$ins_data = array(
@@ -1311,7 +1210,7 @@ if ($page == 'customers'
 						$ins_stmt = Database::prepare("
 							INSERT INTO `".TABLE_DOMAINTOIP."` SET `id_domain` = :domainid, `id_ipandports` = :ipid"
 						);
-						Database::pexecute($ins_stmt, array('domainid' => $domainid, 'ipid' => $settings['system']['defaultip']));
+						Database::pexecute($ins_stmt, array('domainid' => $domainid, 'ipid' => Settings::Get('system.defaultip')));
 
 						$upd_stmt = Database::prepare("
 							UPDATE `" . TABLE_PANEL_CUSTOMERS . "` SET `standardsubdomain` = :domainid WHERE `customerid` = :customerid"
@@ -1382,7 +1281,7 @@ if ($page == 'customers'
 						Database::needRoot(true);
 						$last_dbserver = 0;
 
-						$dbm = new DbManager($settings, $log);
+						$dbm = new DbManager($log);
 
 						// For each of them
 						while ($row_database = $databases_stmt->fetch(PDO::FETCH_ASSOC)) {
@@ -1393,7 +1292,7 @@ if ($page == 'customers'
 								$last_dbserver = $row_database['dbserver'];
 							}
 
-							foreach (array_unique(explode(',', $settings['system']['mysql_access_host'])) as $mysql_access_host) {
+							foreach (array_unique(explode(',', Settings::Get('system.mysql_access_host'))) as $mysql_access_host) {
 								$mysql_access_host = trim($mysql_access_host);
 
 								// Prevent access, if deactivated
@@ -1456,10 +1355,7 @@ if ($page == 'customers'
 						'phpenabled' => $phpenabled,
 						'imap' => $email_imap,
 						'pop3' => $email_pop3,
-						'aps' => $number_of_aps_packages,
-						'perlenabled' => $perlenabled,
-						'email_autoresponder' => $email_autoresponder,
-						'backup_allowed' => $backup_allowed
+						'perlenabled' => $perlenabled
 					);
 					$upd_stmt = Database::prepare("
 						UPDATE `" . TABLE_PANEL_CUSTOMERS . "` SET
@@ -1490,10 +1386,7 @@ if ($page == 'customers'
 						`email_quota` = :email_quota,
 						`imap` = :imap,
 						`pop3` = :pop3,
-						`aps_packages` = :aps,
-						`perlenabled` = :perlenabled,
-						`email_autoresponder` = :email_autoresponder,
-						`backup_allowed` = :backup_allowed
+						`perlenabled` = :perlenabled
 						WHERE `customerid` = :customerid"
 					);
 					Database::pexecute($upd_stmt, $upd_data);
@@ -1558,17 +1451,6 @@ if ($page == 'customers'
 						}
 					}
 
-					if ($email_autoresponder != '-1' || $result['email_autoresponder'] != '-1') {
-						$admin_update_query.= ", `email_autoresponder_used` = `email_autoresponder_used` ";
-
-						if ($email_autoresponder != '-1') {
-							$admin_update_query.= " + 0" . (int)$email_autoresponder . " ";
-						}
-						if ($result['email_autoresponder'] != '-1') {
-							$admin_update_query.= " - 0" . (int)$result['email_autoresponder'] . " ";
-						}
-					}
-
 					if ($subdomains != '-1' || $result['subdomains'] != '-1') {
 						$admin_update_query.= ", `subdomains_used` = `subdomains_used` ";
 
@@ -1613,17 +1495,6 @@ if ($page == 'customers'
 						}
 					}
 
-					if ($number_of_aps_packages != '-1' || $result['aps_packages'] != '-1') {
-						$admin_update_query.= ", `aps_packages_used` = `aps_packages_used` ";
-
-						if ($number_of_aps_packages != '-1') {
-							$admin_update_query.= " + 0" . (int)$number_of_aps_packages . " ";
-						}
-						if ($result['aps_packages'] != '-1') {
-							$admin_update_query.= " - 0" . (int)$result['aps_packages'] . " ";
-						}
-					}
-
 					$admin_update_query.= " WHERE `adminid` = '" . (int)$result['adminid'] . "'";
 					Database::query($admin_update_query);
 					$log->logAction(ADM_ACTION, LOG_INFO, "edited user '" . $result['loginname'] . "'");
@@ -1642,8 +1513,9 @@ if ($page == 'customers'
 					$language_options.= makeoption($language_name, $language_file, $result['def_language'], true);
 				}
 
-				$result['traffic'] = round($result['traffic'] / (1024 * 1024), $settings['panel']['decimal_places']);
-				$result['diskspace'] = round($result['diskspace'] / 1024, $settings['panel']['decimal_places']);
+				$dec_places = Settings::Get('panel.decimal_places');
+				$result['traffic'] = round($result['traffic'] / (1024 * 1024), $dec_places);
+				$result['diskspace'] = round($result['diskspace'] / 1024, $dec_places);
 				$result['email'] = $idna_convert->decode($result['email']);
 
 				$diskspace_ul = makecheckbox('diskspace_ul', $lng['customer']['unlimited'], '-1', false, $result['diskspace'], true, true);
@@ -1681,11 +1553,6 @@ if ($page == 'customers'
 					$result['email_quota'] = '';
 				}
 
-				$email_autoresponder_ul = makecheckbox('email_autoresponder_ul', $lng['customer']['unlimited'], '-1', false, $result['email_autoresponder'], true, true);
-				if ($result['email_autoresponder'] == '-1') {
-					$result['email_autoresponder'] = '';
-				}
-
 				$ftps_ul = makecheckbox('ftps_ul', $lng['customer']['unlimited'], '-1', false, $result['ftps'], true, true);
 				if ($result['ftps'] == '-1') {
 					$result['ftps'] = '';
@@ -1701,11 +1568,6 @@ if ($page == 'customers'
 					$result['mysqls'] = '';
 				}
 
-				$number_of_aps_packages_ul = makecheckbox('number_of_aps_packages_ul', $lng['customer']['unlimited'], '-1', false, $result['aps_packages'], true, true);
-				if ($result['aps_packages'] == '-1') {
-					$result['aps_packages'] = '';
-				}
-
 				$result = htmlentities_array($result);
 
 				$gender_options = makeoption($lng['gender']['undef'], 0, ($result['gender'] == '0' ? true : false), true, true);
