@@ -51,7 +51,7 @@ if ($page == 'domains'
 			'c.loginname' => $lng['login']['username'],
 			'd.aliasdomain' => $lng['domains']['aliasdomain']
 		);
-		$paging = new paging($userinfo, TABLE_PANEL_DOMAINS, $fields, $settings['panel']['paging'], $settings['panel']['natsorting']);
+		$paging = new paging($userinfo, TABLE_PANEL_DOMAINS, $fields);
 		$domains = '';
 		$result_stmt = Database::prepare("
 			SELECT `d`.*, `c`.`loginname`, `c`.`name`, `c`.`firstname`, `c`.`company`, `c`.`standardsubdomain`, `ad`.`id` AS `aliasdomainid`, `ad`.`domain` AS `aliasdomain`
@@ -179,11 +179,6 @@ if ($page == 'domains'
 			if (isset($_POST['send'])
 				&& $_POST['send'] == 'send'
 			) {
-				//check for APS packages used with this domain, #110
-				if (domainHasApsInstances($id)) {
-					standard_error('domains_cantdeletedomainwithapsinstances');
-				}
-
 				// check for deletion of main-domains which are logically subdomains, #329
 				$rsd_sql = '';
 				$remove_subbutmain_domains = isset($_POST['delete_userfiles']) ? 1 : 0;
@@ -288,7 +283,7 @@ if ($page == 'domains'
 				&& $_POST['send'] == 'send'
 			) {
 
-				if ($_POST['domain'] == $settings['system']['hostname']) {
+				if ($_POST['domain'] == Settings::Get('system.hostname')) {
 					standard_error('admin_domain_emailsystemhostname');
 					exit;
 				}
@@ -356,7 +351,14 @@ if ($page == 'domains'
 					$admin = $userinfo;
 				}
 
-				$documentroot = $customer['documentroot'];
+				// set default path if admin/reseller has "change_serversettings == false" but we still
+				// need to respect the documentroot_use_default_value - setting
+				$path_suffix = '';
+				if (Settings::Get('system.documentroot_use_default_value') == 1) {
+					$path_suffix = '/'.$domain;
+				}
+				$documentroot = makeCorrectDir($customer['documentroot'] . $path_suffix);
+
 				$registration_date = trim($_POST['registration_date']);
 				$registration_date = validate($registration_date, 'registration_date', '/^(19|20)\d\d[-](0[1-9]|1[012])[-](0[1-9]|[12][0-9]|3[01])$/', '', array('0000-00-00', '0', ''));
 
@@ -366,7 +368,7 @@ if ($page == 'domains'
 
 					$isbinddomain = '0';
 					$zonefile = '';
-					if ($settings['system']['bind_enable'] == '1') {
+					if (Settings::Get('system.bind_enable') == '1') {
 						if (isset($_POST['isbinddomain'])) {
 							$isbinddomain = intval($_POST['isbinddomain']);
 						}
@@ -396,14 +398,14 @@ if ($page == 'domains'
 						}
 					} elseif (isset($_POST['documentroot'])
 						&& ($_POST['documentroot'] == '') 
-						&& ($settings['system']['documentroot_use_default_value'] == 1)
+						&& (Settings::Get('system.documentroot_use_default_value') == 1)
 					) {
 						$documentroot = makeCorrectDir($customer['documentroot'] . '/' . $domain);
 					}
 
 				} else {
 					$isbinddomain = '0';
-					if ($settings['system']['bind_enable'] == '1') {
+					if (Settings::Get('system.bind_enable') == '1') {
 						$isbinddomain = '1';
 					}
 					$caneditdomain = '1';
@@ -418,8 +420,8 @@ if ($page == 'domains'
 
 					$openbasedir = isset($_POST['openbasedir']) ? intval($_POST['openbasedir']) : 0;
 
-					if ((int)$settings['system']['mod_fcgid'] == 1
-						|| (int)$settings['phpfpm']['enabled'] == 1
+					if ((int)Settings::Get('system.mod_fcgid') == 1
+						|| (int)Settings::Get('phpfpm.enabled') == 1
 					) {
 						$phpsettingid = (int)$_POST['phpsettingid'];
 						$phpsettingid_check_stmt = Database::prepare("
@@ -435,7 +437,7 @@ if ($page == 'domains'
 							standard_error('phpsettingidwrong');
 						}
 
-						if ((int)$settings['system']['mod_fcgid'] == 1) {
+						if ((int)Settings::Get('system.mod_fcgid') == 1) {
 							$mod_fcgid_starter = validate($_POST['mod_fcgid_starter'], 'mod_fcgid_starter', '/^[0-9]*$/', '', array('-1', ''));
 							$mod_fcgid_maxrequests = validate($_POST['mod_fcgid_maxrequests'], 'mod_fcgid_maxrequests', '/^[0-9]*$/', '', array('-1', ''));
 						} else {
@@ -445,10 +447,10 @@ if ($page == 'domains'
 
 					} else {
 
-						if ((int)$settings['phpfpm']['enabled'] == 1) {
-							$phpsettingid = $settings['phpfpm']['defaultini'];
+						if ((int)Settings::Get('phpfpm.enabled') == 1) {
+							$phpsettingid = Settings::Get('phpfpm.defaultini');
 						} else {
-							$phpsettingid = $settings['system']['mod_fcgid_defaultini'];
+							$phpsettingid = Settings::Get('system.mod_fcgid_defaultini');
 						}
 						$mod_fcgid_starter = '-1';
 						$mod_fcgid_maxrequests = '-1';
@@ -457,10 +459,10 @@ if ($page == 'domains'
 				} else {
 
 					$openbasedir = '1';
-					if ((int)$settings['phpfpm']['enabled'] == 1) {
-						$phpsettingid = $settings['phpfpm']['defaultini'];
+					if ((int)Settings::Get('phpfpm.enabled') == 1) {
+						$phpsettingid = Settings::Get('phpfpm.defaultini');
 					} else {
-						$phpsettingid = $settings['system']['mod_fcgid_defaultini'];
+						$phpsettingid = Settings::Get('system.mod_fcgid_defaultini');
 					}
 					$mod_fcgid_starter = '-1';
 					$mod_fcgid_maxrequests = '-1';
@@ -469,10 +471,10 @@ if ($page == 'domains'
 				if ($userinfo['ip'] != "-1") {
 					$admin_ip_stmt = Database::prepare("
 						SELECT `id`, `ip`, `port` FROM `" . TABLE_PANEL_IPSANDPORTS . "`
-						WHERE `id` = :ip ORDER BY `ip`, `port` ASC"
+						WHERE `id` = :id ORDER BY `ip`, `port` ASC"
 					);
 					$admin_ip = Database::pexecute_first($admin_ip_stmt, array('id' => $userinfo['ip']));
-					$additional_ip_condition = " AND `ip` = '" . $admin_ip['ip'] . "' ";
+					$additional_ip_condition = " AND `ip` = :adminip ";
 					$aip_param = array('adminip' => $admin_ip['ip']);
 				} else {
 					$additional_ip_condition = '';
@@ -506,7 +508,7 @@ if ($page == 'domains'
 					}
 				}
 
-				if ($settings['system']['use_ssl'] == "1"
+				if (Settings::Get('system.use_ssl') == "1"
 					&& isset($_POST['ssl_ipandport'])
 				) {
 					$ssl_redirect = 0;
@@ -651,7 +653,7 @@ if ($page == 'domains'
 					standard_error(array('stringisempty', 'mydomain'));
 				}
 				// Check whether domain validation is enabled and if, validate the domain
-				elseif ($settings['system']['validate_domain'] && !validateDomain($domain)) {
+				elseif (Settings::Get('system.validate_domain') && !validateDomain($domain)) {
 					standard_error(array('stringiswrong', 'mydomain'));
 				} elseif($documentroot == '') {
 					standard_error(array('stringisempty', 'mydocumentroot'));
@@ -749,6 +751,9 @@ if ($page == 'domains'
 						`aliasdomain` = :aliasdomain,
 						`zonefile` = :zonefile,
 						`dkim` = :dkim,
+						`dkim_id` = '0',
+						`dkim_privkey` = '',
+						`dkim_pubkey` = '',
 						`wwwserveralias` = :wwwserveralias,
 						`iswildcarddomain` = :iswildcarddomain,
 						`isbinddomain` = :isbinddomain,
@@ -940,10 +945,10 @@ if ($page == 'domains'
 				$configs = Database::query("SELECT * FROM `" . TABLE_PANEL_PHPCONFIGS . "`");
 
 				while ($row = $configs->fetch(PDO::FETCH_ASSOC)) {
-					if ((int)$settings['phpfpm']['enabled'] == 1) {
-						$phpconfigs.= makeoption($row['description'], $row['id'], $settings['phpfpm']['defaultini'], true, true);
+					if ((int)Settings::Get('phpfpm.enabled') == 1) {
+						$phpconfigs.= makeoption($row['description'], $row['id'], Settings::Get('phpfpm.defaultini'), true, true);
 					} else {
-						$phpconfigs.= makeoption($row['description'], $row['id'], $settings['system']['mod_fcgid_defaultini'], true, true);
+						$phpconfigs.= makeoption($row['description'], $row['id'], Settings::Get('system.mod_fcgid_defaultini'), true, true);
 					}
 				}
 
@@ -1051,7 +1056,7 @@ if ($page == 'domains'
 
 				if ($customerid > 0
 					&& $customerid != $result['customerid']
-					&& $settings['panel']['allow_domain_change_customer'] == '1'
+					&& Settings::Get('panel.allow_domain_change_customer') == '1'
 				) {
 
 					$customer_stmt = Database::prepare("
@@ -1099,7 +1104,7 @@ if ($page == 'domains'
 
 					if ($adminid > 0
 						&& $adminid != $result['adminid']
-						&& $settings['panel']['allow_domain_change_admin'] == '1'
+						&& Settings::Get('panel.allow_domain_change_admin') == '1'
 					) {
 
 						$admin_stmt = Database::prepare("
@@ -1155,7 +1160,7 @@ if ($page == 'domains'
 				if ($userinfo['change_serversettings'] == '1') {
 					$isbinddomain = $result['isbinddomain'];
 					$zonefile = $result['zonefile'];
-					if ($settings['system']['bind_enable'] == '1') {
+					if (Settings::Get('system.bind_enable') == '1') {
 						if (isset($_POST['isbinddomain'])) {
 							$isbinddomain = (int)$_POST['isbinddomain'];
 						} else {
@@ -1164,7 +1169,7 @@ if ($page == 'domains'
 						$zonefile = validate($_POST['zonefile'], 'zonefile');
 					}
 
-					if ($settings['dkim']['use_dkim'] == '1') {
+					if (Settings::Get('dkim.use_dkim') == '1') {
 						$dkim = isset($_POST['dkim']) ? 1 : 0;
 					} else {
 						$dkim = $result['dkim'];
@@ -1176,7 +1181,7 @@ if ($page == 'domains'
 					if ($documentroot == '') {
 						// If path is empty and 'Use domain name as default value for DocumentRoot path' is enabled in settings,
 						// set default path to subdomain or domain name
-						if ($settings['system']['documentroot_use_default_value'] == 1) {
+						if (Settings::Get('system.documentroot_use_default_value') == 1) {
 							$documentroot = makeCorrectDir($customer['documentroot'] . '/' . $result['domain']);
 						} else {
 							$documentroot = $customer['documentroot'];
@@ -1205,8 +1210,8 @@ if ($page == 'domains'
 
 					$openbasedir = isset($_POST['openbasedir']) ? intval($_POST['openbasedir']) : 0;
 
-					if ((int)$settings['system']['mod_fcgid'] == 1
-						|| (int)$settings['phpfpm']['enabled'] == 1
+					if ((int)Settings::Get('system.mod_fcgid') == 1
+						|| (int)Settings::Get('phpfpm.enabled') == 1
 					) {
 						$phpsettingid = (int)$_POST['phpsettingid'];
 						$phpsettingid_check_stmt = Database::prepare("
@@ -1221,7 +1226,7 @@ if ($page == 'domains'
 							standard_error('phpsettingidwrong');
 						}
 
-						if ((int)$settings['system']['mod_fcgid'] == 1) {
+						if ((int)Settings::Get('system.mod_fcgid') == 1) {
 							$mod_fcgid_starter = validate($_POST['mod_fcgid_starter'], 'mod_fcgid_starter', '/^[0-9]*$/', '', array('-1', ''));
 							$mod_fcgid_maxrequests = validate($_POST['mod_fcgid_maxrequests'], 'mod_fcgid_maxrequests', '/^[0-9]*$/', '', array('-1', ''));
 						} else {
@@ -1266,7 +1271,7 @@ if ($page == 'domains'
 					}
 				}
 
-				if ($settings['system']['use_ssl'] == '1'
+				if (Settings::Get('system.use_ssl') == '1'
 					&& isset($_POST['ssl_ipandport'])
 				) {
 					$ssl = 1; // if ssl is set and != 0, it can only be 1
@@ -1495,7 +1500,7 @@ if ($page == 'domains'
 				}
 
 				if ($customerid != $result['customerid']
-					&& $settings['panel']['allow_domain_change_customer'] == '1'
+					&& Settings::Get('panel.allow_domain_change_customer') == '1'
 				) {
 					$upd_data = array('customerid' => $customerid, 'domainid' => $result['id']);
 					$upd_stmt = Database::prepare("
@@ -1531,7 +1536,7 @@ if ($page == 'domains'
 				}
 
 				if ($adminid != $result['adminid']
-					&& $settings['panel']['allow_domain_change_admin'] == '1'
+					&& Settings::Get('panel.allow_domain_change_admin') == '1'
 				) {
 					$upd_stmt = Database::prepare("
 						UPDATE `" . TABLE_PANEL_ADMINS . "` SET `domains_used` = `domains_used` + 1 WHERE `adminid` = :adminid
@@ -1624,6 +1629,13 @@ if ($page == 'domains'
 				$_update_data['mod_fcgid_maxrequests'] = $mod_fcgid_maxrequests;
 				$_update_data['parentdomainid'] = $id;
 
+				// if we have no more ssl-ip's for this domain,
+				// all its subdomains must have "ssl-redirect = 0"
+				$update_sslredirect = '';
+				if (count($ssl_ipandports) == 1 && $ssl_ipandports[0] == -1) {
+					$update_sslredirect = ", `ssl_redirect` = '0' ";
+				}
+
 				$_update_stmt = Database::prepare("
 					UPDATE `" . TABLE_PANEL_DOMAINS . "` SET
 					`customerid` = :customerid,
@@ -1632,7 +1644,7 @@ if ($page == 'domains'
 					`phpsettingid` = :phpsettingid,
 					`mod_fcgid_starter` = :mod_fcgid_starter,
 					`mod_fcgid_maxrequests` = :mod_fcgid_maxrequests
-					" . $upd_specialsettings . $updatechildren . " 
+					" . $upd_specialsettings . $updatechildren . $update_sslredirect . "
 					WHERE `parentdomainid` = :parentdomainid
 				");
 				Database::pexecute($_update_stmt, $_update_data);
@@ -1693,7 +1705,7 @@ if ($page == 'domains'
 			} else {
 
 
-				if ($settings['panel']['allow_domain_change_customer'] == '1') {
+				if (Settings::Get('panel.allow_domain_change_customer') == '1') {
 					$customers = '';
 					$result_customers_stmt = Database::prepare("
 						SELECT `customerid`, `loginname`, `name`, `firstname`, `company` FROM `" . TABLE_PANEL_CUSTOMERS . "`
@@ -1730,7 +1742,7 @@ if ($page == 'domains'
 				}
 
 				if ($userinfo['customers_see_all'] == '1') {
-					if ($settings['panel']['allow_domain_change_admin'] == '1') {
+					if (Settings::Get('panel.allow_domain_change_admin') == '1') {
 
 						$admins = '';
 						$result_admins_stmt = Database::prepare("
