@@ -23,7 +23,7 @@ require './lib/init.php';
 $id = 0;
 if (isset($_POST['id'])) {
 	$id = intval($_POST['id']);
-} elseif(isset($_GET['id'])) {
+} elseif (isset($_GET['id'])) {
 	$id = intval($_GET['id']);
 }
 
@@ -35,13 +35,13 @@ if ($page == 'overview') {
 		$log->logAction(USR_ACTION, LOG_NOTICE, "viewed customer_ftp::accounts");
 		$fields = array(
 			'username' => $lng['login']['username'],
-			'homedir' => $lng['panel']['path']
+			'homedir' => $lng['panel']['path'],
+			'description' => $lng['panel']['ftpdesc']
 		);
-		$paging = new paging($userinfo, TABLE_FTP_USERS, $fields, $settings['panel']['paging'], $settings['panel']['natsorting']);
+		$paging = new paging($userinfo, TABLE_FTP_USERS, $fields);
 
-		$result_stmt = Database::prepare("SELECT `id`, `username`, `homedir` FROM `" . TABLE_FTP_USERS . "`
-			WHERE `customerid`= :customerid 
-			AND `username` NOT LIKE '%_backup'" . $paging->getSqlWhere(true) . " " . $paging->getSqlOrderBy() . " " . $paging->getSqlLimit()
+		$result_stmt = Database::prepare("SELECT `id`, `username`, `description`, `homedir` FROM `" . TABLE_FTP_USERS . "`
+			WHERE `customerid`= :customerid " . $paging->getSqlWhere(true) . " " . $paging->getSqlOrderBy() . " " . $paging->getSqlLimit()
 		);
 		Database::pexecute($result_stmt, array("customerid" => $userinfo['customerid']));
 		$ftps_count = Database::num_rows();
@@ -147,7 +147,8 @@ if ($page == 'overview') {
 	} elseif ($action == 'add') {
 		if ($userinfo['ftps_used'] < $userinfo['ftps'] || $userinfo['ftps'] == '-1') {
 			if (isset($_POST['send'])
-			   && $_POST['send'] == 'send') {
+				&& $_POST['send'] == 'send') {
+				$description = validate($_POST['ftp_description'], 'description');
 				// @FIXME use a good path-validating regex here (refs #1231)
 				$path = validate($_POST['path'], 'path');
 				$password = validate($_POST['ftp_password'], 'password');
@@ -158,7 +159,7 @@ if ($page == 'overview') {
 					$sendinfomail = 0;
 				}
 
-				if ($settings['customer']['ftpatdomain'] == '1') {
+				if (Settings::Get('customer.ftpatdomain') == '1') {
 					$ftpusername = validate($_POST['ftp_username'], 'username', '/^[a-zA-Z0-9][a-zA-Z0-9\-_]+\$?$/');
 					if ($ftpusername == '') {
 						standard_error(array('stringisempty', 'username'));
@@ -176,7 +177,7 @@ if ($page == 'overview') {
 					}
 					$username = $ftpusername . "@" . $ftpdomain;
 				} else {
-					$username = $userinfo['loginname'] . $settings['customer']['ftpprefix'] . (intval($userinfo['ftp_lastaccountnumber']) + 1);
+					$username = $userinfo['loginname'] . Settings::Get('customer.ftpprefix') . (intval($userinfo['ftp_lastaccountnumber']) + 1);
 				}
 
 				$username_check_stmt = Database::prepare("SELECT * FROM `" . TABLE_FTP_USERS . "`
@@ -191,18 +192,21 @@ if ($page == 'overview') {
 					standard_error(array('stringisempty', 'mypassword'));
 				} elseif ($path == '') {
 					standard_error('patherror');
+				} elseif ($username == $password) {
+					standard_error('passwordshouldnotbeusername');
 				} else {
 					$path = makeCorrectDir($userinfo['documentroot'] . '/' . $path);
 
 					$cryptPassword = makeCryptPassword($password);
 
 					$stmt = Database::prepare("INSERT INTO `" . TABLE_FTP_USERS . "`
-						(`customerid`, `username`, `password`, `homedir`, `login_enabled`, `uid`, `gid`)
-						VALUES (:customerid, :username, :password, :homedir, 'y', :guid, :guid)"
+						(`customerid`, `username`, `description`, `password`, `homedir`, `login_enabled`, `uid`, `gid`)
+						VALUES (:customerid, :username, :description, :password, :homedir, 'y', :guid, :guid)"
 					);
 					$params = array(
 						"customerid" => $userinfo['customerid'],
 						"username" => $username,
+						"description" => $description,
 						"password" => $cryptPassword,
 						"homedir" => $path,
 						"guid" => $userinfo['guid']
@@ -216,7 +220,7 @@ if ($page == 'overview') {
 
 					while ($row = $result_stmt->fetch(PDO::FETCH_ASSOC)) {
 						$stmt = Database::prepare("INSERT INTO `" . TABLE_FTP_QUOTATALLIES . "`
-							(`name`, `quota_type`, `bytes_in_used`, `bytes_out_used`, `bytes_xfer_used`, `files_in_used`, `files_out_used`, `files_xfer_used`) 
+							(`name`, `quota_type`, `bytes_in_used`, `bytes_out_used`, `bytes_xfer_used`, `files_in_used`, `files_out_used`, `files_xfer_used`)
 							VALUES (:name, 'user', :bytes_in_used, '0', '0', '0', '0', '0')"
 						);
 						Database::pexecute($stmt, array("name" => $username, "bytes_in_used" => $row['bytes_in_used']));
@@ -298,12 +302,12 @@ if ($page == 'overview') {
 						$mail->ClearAddresses();
 					}
 
-					redirectTo($filename, Array('page' => $page, 's' => $s));
+					redirectTo($filename, array('page' => $page, 's' => $s));
 				}
 			} else {
 				$pathSelect = makePathfield($userinfo['documentroot'], $userinfo['guid'], $userinfo['guid'], '/');
 
-				if ($settings['customer']['ftpatdomain'] == '1') {
+				if (Settings::Get('customer.ftpatdomain') == '1') {
 					$domainlist = array();
 					$domains = '';
 
@@ -337,7 +341,7 @@ if ($page == 'overview') {
 			}
 		}
 	} elseif ($action == 'edit' && $id != 0) {
-		$result_stmt = Database::prepare("SELECT `id`, `username`, `homedir`, `uid`, `gid` FROM `" . TABLE_FTP_USERS . "`
+		$result_stmt = Database::prepare("SELECT `id`, `username`, `description`, `homedir`, `uid`, `gid` FROM `" . TABLE_FTP_USERS . "`
 			WHERE `customerid` = :customerid
 			AND `id` = :id"
 		);
@@ -360,6 +364,9 @@ if ($page == 'overview') {
 					if ($password == '') {
 						standard_error(array('stringisempty', 'mypassword'));
 						exit;
+					} elseif ($result['username'] == $password) {
+						standard_error('passwordshouldnotbeusername');
+						exit;
 					}
 					$log->logAction(USR_ACTION, LOG_INFO, "updated ftp-account password for '" . $result['username'] . "'");
 					$cryptPassword = makeCryptPassword($password);
@@ -370,21 +377,6 @@ if ($page == 'overview') {
 						AND `id` = :id"
 					);
 					Database::pexecute($stmt, array("customerid" => $userinfo['customerid'], "id" => $id, "password" => $cryptPassword));
-
-					// also update customers backup user password if password of main ftp user is changed
-					if(!preg_match('/' . $settings['customer']['ftpprefix'] . '/', $result['username'])) {
-						$stmt = Database::prepare("UPDATE `" . TABLE_FTP_USERS . "`
-							SET `password` = :password
-							WHERE `customerid` = :customerid
-							AND `username` = :username"
-						);
-						$params = array(
-							"password" => $cryptPassword,
-							"customerid" => $userinfo['customerid'],
-							"username" => $result['username'] . "_backup"
-						);
-						Database::pexecute($stmt, $params);
-					}
 				}
 
 				if ($path != '') {
@@ -392,7 +384,7 @@ if ($page == 'overview') {
 
 					if ($path != $result['homedir']) {
 						if (!file_exists($path)) {
-							// it's the task for "new ftp" but that will 
+							// it's the task for "new ftp" but that will
 							// create all directories and correct their permissions
 							inserttask(5);
 						}
@@ -413,7 +405,16 @@ if ($page == 'overview') {
 					}
 				}
 
-				redirectTo($filename, Array('page' => $page, 's' => $s));
+				$log->logAction(USR_ACTION, LOG_INFO, "edited ftp-account '" . $result['username'] . "'");
+				$description = validate($_POST['ftp_description'], 'description');
+				$stmt = Database::prepare("UPDATE `" . TABLE_FTP_USERS . "`
+					SET `description` = :desc
+					WHERE `customerid` = :customerid
+					AND `id` = :id"
+				);
+				Database::pexecute($stmt, array("desc" => $description, "customerid" => $userinfo['customerid'], "id" => $id));
+
+				redirectTo($filename, array('page' => $page, 's' => $s));
 			} else {
 				if (strpos($result['homedir'], $userinfo['documentroot']) === 0) {
 					$homedir = substr($result['homedir'], strlen($userinfo['documentroot']));
@@ -424,7 +425,7 @@ if ($page == 'overview') {
 
 				$pathSelect = makePathfield($userinfo['documentroot'], $userinfo['guid'], $userinfo['guid'], $homedir);
 
-				if ($settings['customer']['ftpatdomain'] == '1') {
+				if (Settings::Get('customer.ftpatdomain') == '1') {
 					$domains = '';
 
 					$result_domains_stmt = Database::prepare("SELECT `domain` FROM `" . TABLE_PANEL_DOMAINS . "`
