@@ -65,7 +65,8 @@ class FroxlorInstall {
 	 */
 	private $_languages = array(
 			'german' => 'Deutsch',
-			'english' => 'English'
+			'english' => 'English',
+			'french' => 'Français'
 	);
 
 	/**
@@ -275,7 +276,7 @@ class FroxlorInstall {
 			$navigation = '';
 			$msgcolor = 'red';
 			$message = $this->_lng['install']['testing_mysql_fail'];
-			$link = 'install.php';
+			$link = 'install.php?check=1';
 			$linktext = $this->_lng['click_here_to_goback'];
 		} else {
 			// all good
@@ -398,10 +399,7 @@ class FroxlorInstall {
 				`tickets` = -1,
 				`tickets_see_all` = 1,
 				`subdomains` = -1,
-				`traffic` = -1048576,
-				`can_manage_aps_packages` = 1,
-				`aps_packages` = -1,
-				`email_autoresponder` = -1
+				`traffic` = -1048576
 				");
 
 		$ins_stmt->execute($ins_data);
@@ -908,15 +906,14 @@ class FroxlorInstall {
 			$content .= $this->_status_message('green', $this->_lng['requirements']['installed']);
 		}
 
-                // check for curl extension
-                $content .= $this->_status_message('begin', $this->_lng['requirements']['phpcurl']);
-
-                if (!extension_loaded('curl')) {
-                        $content .= $this->_status_message('orange', $this->_lng['requirements']['notinstalled'] . "<br />" . $this->_lng['requirements']['curldescription']);
-                } else {
-                        $content .= $this->_status_message('green', $this->_lng['requirements']['installed']);
-                }
+		// check for curl extension
+		$content .= $this->_status_message('begin', $this->_lng['requirements']['phpcurl']);
 
+		if (!extension_loaded('curl')) {
+			$content .= $this->_status_message('orange', $this->_lng['requirements']['notinstalled'] . "<br />" . $this->_lng['requirements']['curldescription']);
+		} else {
+			$content .= $this->_status_message('green', $this->_lng['requirements']['installed']);
+		}
 
 		// check for open_basedir
 		$content .= $this->_status_message('begin', $this->_lng['requirements']['openbasedir']);
