@@ -38,16 +38,16 @@ return array(
 						'label' => $lng['admin']['stdsubdomain_add'].'?',
 						'type' => 'checkbox',
 						'values' => array(
-										array ('label' => $lng['panel']['yes'], 'value' => '1')
-									),
+							array ('label' => $lng['panel']['yes'], 'value' => '1')
+						),
 						'value' => array(($result['standardsubdomain'] != '0') ? '1' : '0')
 					),
 					'deactivated' => array(
 						'label' => $lng['admin']['deactivated_user'],
 						'type' => 'checkbox',
 						'values' => array(
-										array ('label' => $lng['panel']['yes'], 'value' => '1')
-									),
+							array ('label' => $lng['panel']['yes'], 'value' => '1')
+						),
 						'value' => array($result['deactivated'])
 					),
 					'new_customer_password' => array(
@@ -189,24 +189,16 @@ return array(
 						'type' => 'textul',
 						'value' => $result['email_quota'],
 						'maxlength' => 9,
-						'visible' => ($settings['system']['mail_quota_enabled'] == '1' ? true : false),
+						'visible' => (Settings::Get('system.mail_quota_enabled') == '1' ? true : false),
 						'mandatory' => true,
 						'ul_field' => $email_quota_ul
 					),
-					'email_autoresponder' => array(
-						'label' => $lng['customer']['autoresponder'],
-						'type' => 'textul',
-						'value' => $result['email_autoresponder'],
-						'maxlength' => 9,
-						'visible' => ($settings['autoresponder']['autoresponder_active'] == '1' ? true : false),
-						'ul_field' => $email_autoresponder_ul
-					),
 					'email_imap' => array(
 						'label' => $lng['customer']['email_imap'],
 						'type' => 'checkbox',
 						'values' => array(
-										array ('label' => $lng['panel']['yes'], 'value' => '1')
-									),
+							array ('label' => $lng['panel']['yes'], 'value' => '1')
+						),
 						'value' => array($result['imap']),
 						'mandatory' => true
 					),
@@ -214,8 +206,8 @@ return array(
 						'label' => $lng['customer']['email_pop3'],
 						'type' => 'checkbox',
 						'values' => array(
-										array ('label' => $lng['panel']['yes'], 'value' => '1')
-									),
+							array ('label' => $lng['panel']['yes'], 'value' => '1')
+						),
 						'value' => array($result['pop3']),
 						'mandatory' => true
 					),
@@ -231,7 +223,7 @@ return array(
 						'type' => 'textul',
 						'value' => $result['tickets'],
 						'maxlength' => 9,
-						'visible' => ($settings['ticket']['enabled'] == '1' ? true : false),
+						'visible' => (Settings::Get('ticket.enabled') == '1' ? true : false),
 						'ul_field' => $tickets_ul
 					),
 					'mysqls' => array(
@@ -246,32 +238,17 @@ return array(
 						'label' => $lng['admin']['phpenabled'].'?',
 						'type' => 'checkbox',
 						'values' => array(
-										array ('label' => $lng['panel']['yes'], 'value' => '1')
-									),
+							array ('label' => $lng['panel']['yes'], 'value' => '1')
+						),
 						'value' => array($result['phpenabled'])
 					),
 					'perlenabled' => array(
 						'label' => $lng['admin']['perlenabled'].'?',
 						'type' => 'checkbox',
 						'values' => array(
-										array ('label' => $lng['panel']['yes'], 'value' => '1')
-									),
+							array ('label' => $lng['panel']['yes'], 'value' => '1')
+						),
 						'value' => array($result['perlenabled'])
-					),
-					'backup_allowed' => array(
-						'label' => $lng['backup_allowed'].'?',
-						'type' => 'yesno',
-						'value' => 0,
-						'yesno_var' => $backup_allowed,
-						'visible' => ($settings['system']['backup_enabled'] == '1' ? true : false)
-					),
-					'number_of_aps_packages' => array(
-						'label' => $lng['aps']['numberofapspackages'],
-						'type' => 'textul',
-						'value' => $result['aps_packages'],
-						'maxlength' => 9,
-						'visible' => ($settings['aps']['aps_active'] == '1' ? true : false),
-						'ul_field' => $number_of_aps_packages_ul
 					)
 				)
 			)
