@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Functions
- * @version    $Id$
+ *
  */
 
 /**
@@ -42,7 +42,7 @@ function validateDomain($domainname)
 	// a dash (-) in it. As the PHP_VERSION constant
 	// gives also patch-brandings, e.g. '5.3.2-pl0-gentoo'
 	// we just always use our regex
-	$pattern = '/^http:\/\/([a-z0-9]([a-z0-9\-]{0,61}[a-z0-9])?\.)+[a-z]{2,6}$/i';
+	$pattern = '/^http:\/\/([a-z0-9]([a-z0-9\-]{0,61}[a-z0-9])?\.)+[a-z0-9\-]{2,63}$/i';
 	if(preg_match($pattern, $domainname_tmp))
 	{	
 		return $domainname;
