@@ -143,10 +143,17 @@ while ($row_database = $databases_stmt->fetch(PDO::FETCH_ASSOC)) {
 Database::needRoot(false);
 
 // We are using the file-system quota, this will speed up the diskusage - collection
-if ($settings['system']['diskquota_enabled']) {
+if (Settings::Get('system.diskquota_enabled')) {
 	$usedquota = getFilesystemQuota();
 }
 
+/**
+ * MAIL-Traffic
+ */
+if (Settings::Get("system.mailtraffic_enabled")) {
+	$mailTrafficCalc = new MailLogParser(Settings::Get("system.last_traffic_run"));
+}
+
 $result_stmt = Database::query("SELECT * FROM `" . TABLE_PANEL_CUSTOMERS . "` ORDER BY `customerid` ASC");
 
 while ($row = $result_stmt->fetch(PDO::FETCH_ASSOC)) {
@@ -157,8 +164,8 @@ while ($row = $result_stmt->fetch(PDO::FETCH_ASSOC)) {
 	$httptraffic = 0;
 
 	if (isset($domainlist[$row['customerid']])
-	   && is_array($domainlist[$row['customerid']])
-	   && count($domainlist[$row['customerid']]) != 0
+		&& is_array($domainlist[$row['customerid']])
+		&& count($domainlist[$row['customerid']]) != 0
 	) {
 		// Examining which caption to use for default webalizer stats...
 		if ($row['standardsubdomain'] != '0') {
@@ -172,7 +179,7 @@ while ($row = $result_stmt->fetch(PDO::FETCH_ASSOC)) {
 			foreach ($domainlist[$row['customerid']] as $domainid => $domain) {
 
 				if (!isset($speciallogfile_domainlist[$row['customerid']])
-				   || !isset($speciallogfile_domainlist[$row['customerid']][$domainid])
+					|| !isset($speciallogfile_domainlist[$row['customerid']][$domainid])
 				) {
 					$caption = $domain;
 					break;
@@ -184,11 +191,11 @@ while ($row = $result_stmt->fetch(PDO::FETCH_ASSOC)) {
 		reset($domainlist[$row['customerid']]);
 
 		if (isset($speciallogfile_domainlist[$row['customerid']])
-		   && is_array($speciallogfile_domainlist[$row['customerid']])
-		   && count($speciallogfile_domainlist[$row['customerid']]) != 0
+			&& is_array($speciallogfile_domainlist[$row['customerid']])
+			&& count($speciallogfile_domainlist[$row['customerid']]) != 0
 		) {
 			reset($speciallogfile_domainlist[$row['customerid']]);
-			if ($settings['system']['awstats_enabled'] == '0') {
+			if (Settings::Get('system.awstats_enabled') == '0') {
 				foreach ($speciallogfile_domainlist[$row['customerid']] as $domainid => $domain) {
 					$httptraffic+= floatval(callWebalizerGetTraffic($row['loginname'] . '-' . $domain, $row['documentroot'] . '/webalizer/' . $domain . '/', $domain, $domainlist[$row['customerid']]));
 				}
@@ -201,7 +208,7 @@ while ($row = $result_stmt->fetch(PDO::FETCH_ASSOC)) {
 		// *not* also in the special-logfiles-loop, because the function
 		// will iterate through all customer-domains and the awstats-configs
 		// know the logfile-name, #246
-		if ($settings['system']['awstats_enabled'] == '1') {
+		if (Settings::Get('system.awstats_enabled') == '1') {
 			$httptraffic+= floatval(callAwstatsGetTraffic($row['customerid'], $row['documentroot'] . '/awstats/', $domainlist[$row['customerid']]));
 		} else {
 			$httptraffic+= floatval(callWebalizerGetTraffic($row['loginname'], $row['documentroot'] . '/webalizer/', $caption, $domainlist[$row['customerid']]));
@@ -237,6 +244,48 @@ while ($row = $result_stmt->fetch(PDO::FETCH_ASSOC)) {
 	 * Mail-Traffic
 	 */
 	$mailtraffic = 0;
+	if (Settings::Get("system.mailtraffic_enabled")) {
+		fwrite($debugHandler, 'mail traffic usage for ' . $row['loginname'] . " started...\n");
+
+		$currentDate = date("Y-m-d");
+
+		$domains_stmt = Database::prepare("SELECT domain FROM `" . TABLE_PANEL_DOMAINS . "` WHERE `customerid` = :cid");
+		Database::pexecute($domains_stmt, array("cid" => $row['customerid']));
+		while ($domainRow = $domains_stmt->fetch(PDO::FETCH_ASSOC)) {
+			$domainMailTraffic = $mailTrafficCalc->getDomainTraffic($domainRow["domain"]);
+			if (!is_array($domainMailTraffic)) { continue; }
+
+			foreach ($domainMailTraffic as $dateTraffic => $dayTraffic) {
+				$dayTraffic = floatval($dayTraffic / 1024);
+
+				list($year, $month, $day) = explode("-", $dateTraffic);
+				if ($dateTraffic == $currentDate) {
+					$mailtraffic = $dayTraffic;
+				} else {
+					// Check if an entry for the given day exists
+					$stmt = Database::prepare("SELECT * FROM `" . TABLE_PANEL_TRAFFIC . "`
+						WHERE `customerid` = :cid
+						AND `year` = :year
+						AND `month` = :month
+						AND `day` = :day");
+					$params = array(
+						"cid" => $row['customerid'],
+						"year" => $year,
+						"month" => $month,
+						"day" => $day
+					);
+					Database::pexecute($stmt, $params);
+					if ($stmt->rowCount() > 0) {
+						$updRow = $stmt->fetch(PDO::FETCH_ASSOC);
+						$upd_stmt = Database::prepare("UPDATE `" . TABLE_PANEL_TRAFFIC . "` SET
+							`mail` = :mail
+							WHERE `id` = :id");
+						Database::pexecute($upd_stmt, array("mail" => $updRow['mail'] + $dayTraffic, "id" => $updRow['id']));
+					}
+				}
+			}
+		}
+	}
 
 	/**
 	 * Total Traffic
@@ -306,7 +355,7 @@ while ($row = $result_stmt->fetch(PDO::FETCH_ASSOC)) {
 	$webspaceusage = 0;
 
 	// Using repquota, it's faster using this tool than using du traversing the complete directory
-	if ($settings['system']['diskquota_enabled']
+	if (Settings::Get('system.diskquota_enabled')
 		&& isset($usedquota[$row['guid']]['block']['used'])
 		&& $usedquota[$row['guid']]['block']['used'] >= 1
 	) {
@@ -338,7 +387,7 @@ while ($row = $result_stmt->fetch(PDO::FETCH_ASSOC)) {
 	fwrite($debugHandler, 'calculating mailspace usage for ' . $row['loginname'] . "\n");
 	$emailusage = 0;
 
-	$maildir = makeCorrectDir($settings['system']['vmail_homedir'] . $row['loginname']);
+	$maildir = makeCorrectDir(Settings::Get('system.vmail_homedir') . $row['loginname']);
 	if (file_exists($maildir) && is_dir($maildir)) {
 		$back = safe_exec('du -sk ' . escapeshellarg($maildir) . '');
 		foreach ($back as $backrow) {
@@ -409,14 +458,7 @@ while ($row = $result_stmt->fetch(PDO::FETCH_ASSOC)) {
 	/**
 	 * Total Usage
 	 */
-	if ($settings['system']['backup_count'] == 0
-		&& file_exists($settings['system']['backup_dir'] . $row['loginname'])
-	) {
-		$backupsize = exec('du -s ' . escapeshellarg($settings['system']['backup_dir']) . $row['loginname'] . '');
-		$diskusage = floatval($webspaceusage + $emailusage + $mysqlusage - $backupsize);
-	} else {
-		$diskusage = floatval($webspaceusage + $emailusage + $mysqlusage);
-	}
+	$diskusage = floatval($webspaceusage + $emailusage + $mysqlusage);
 
 	$upd_data = array(
 		'diskspace' => $current_diskspace['all'],
@@ -437,7 +479,7 @@ while ($row = $result_stmt->fetch(PDO::FETCH_ASSOC)) {
 	$upd_data = array(
 		'biu' => ($current_diskspace['all'] * 1024),
 		'loginname' => $row['loginname'],
-		'loginnamelike' => $row['loginname'] . $settings['customer']['ftpprefix'] . "%"
+		'loginnamelike' => $row['loginname'] . Settings::Get('customer.ftpprefix') . "%"
 	);
 	$upd_stmt = Database::prepare("
 		UPDATE `" . TABLE_FTP_QUOTATALLIES . "` SET
@@ -448,7 +490,7 @@ while ($row = $result_stmt->fetch(PDO::FETCH_ASSOC)) {
 	/**
 	 * Pureftpd Quota
 	 */
-	if ($settings['system']['ftpserver'] == "pureftpd") {
+	if (Settings::Get('system.ftpserver') == "pureftpd") {
 
 		$result_quota_stmt = Database::prepare("
 			SELECT homedir FROM `" . TABLE_FTP_USERS . "` WHERE customerid = :customerid
@@ -456,7 +498,7 @@ while ($row = $result_stmt->fetch(PDO::FETCH_ASSOC)) {
 		Database::pexecute($result_quota_stmt, array('customerid' => $row['customerid']));
 
 		// get correct user
-		if ($settings['system']['mod_fcgid'] == 1
+		if (Settings::Get('system.mod_fcgid') == 1
 			&& $row['deactivated'] == '0'
 		) {
 			$user = $row['loginname'];
